/*

Scream of the Stickster

Code for version 2, translated to readable format


Preprocessor section.

Each of the #defines below is used in the regular code, but not in this translated version.

A few things you might see often because of the #defines that don't
otherwise make sense:

	- Vars named "view"; this is because H is a single letter and view is a valid var name.
	  I'd name the var H in this code for simplicity, but then a different map file would
	  have to be used because the map file sets up the var "view" to be loaded with a value.
	- The var name G is used below even though this actually works out to get_step, because
	  unlike H/view this is never pre-loaded with anything from the map. The G var is a
	  global list that keeps track of players' scores during the round if they log out.
	- if(src) del(src) -- The if() check is handy to avoid bugs in some cases, and so q()
	  is used in place of del(). The macro includes a following semicolon, which is also a
	  byte saver. Anywhere in the official code q(a) is used, assume a semicolon follows.
	- max(b-world.time,0). This is used to determine if movement is possible (0) or not (>0).
	  The single underscore _ is used here. In some places this is also represented as
	  if(b>world.time) instead of if(max(b-world.time,0)), even though the regular code uses
	  the underscore.
	- There are no vars named u. This was just the most "convenient" choice to replace #define.
	- Sometimes loc is replaced with K in the official code, and sometimes it isn't. Because of
	  a parsing bug in BYOND 334, anything with K.var or K:var didn't work; I believe K is
	  being replaced with loc followed by whitespace afterward, and BYOND just doesn't
	  understand this.

#define u #define
u i if
u q(a) i(a)del a;
u t world.time
u D density
u E else
u F(a,b) for(a in b)
u G get_step
u H view
u I src
u J icon_state
u K loc
u Kn set category=null
u N name
u O New
u Q world.maxz
u R return
u T locate
u V new
u W while
u X ..()
u Y spawn
u Z sleep
u _ max(b-t,0)
u gd get_dir
u Pf P.Find(I)
*/

var
	list
		L		// global list stored in map file
		P=new	// initialize player list
		G		// persistent scores
	turf
		o/U
		w/w
	obj
		o
		l/l		// ladder object
	mob
		p/M		// a player
		s/S		// the Stickster
	A
	B
	C
	s=41		// world size
	p			// world.time for end of round
	v			// list of direction flags for 47-state open space

world
	New()
		A=w(9)			// locate the turf that has the global list (tagged as "9")
		L=A:k			// get the list
		name=L[1]		// load name from list
		v=L[2]			// load v (direction flags)
		hub=L[7]		// load world.hub
		spawn(50) S()	// begin a round in 5 seconds

	view=6
	turf=/turf/w		// default turf is a wall; maze generator will clear it out
	mob=/mob/p

proc
	// Begin round
	S()
		p=world.time+6009	// set end-of-round time at +10 minutes; add 0.9 seconds for display purposes
		P(1)			// generate a maze, z-level 1
		spawn(6e3) K()	// end round in 6000 ticks (10 minutes)
		G=new			// reset persistent score list
		for(M in P)		// loop through players list
			M.k=0		// reset score to 0
			M.loc=l()	// give the player a random loc

	// End round
	K()
		p=0				// reset timer
		M=P[1]					// display winner message
		P<<L[18]+M.name+L[19]	// L[18] and L[19] are part of that message, on the global list
		for(M in P)
			M.loc=w(0)	// send players to turf tagged "0" (splash screen)
			M:m=6		// reset ammo to 6
		if(S) del(S)	// delete the Stickster
		world.maxz=1	// destroy levels 2-6 if they exist.
		for(o)
			if(o) del(o)	// delete all objs
		for(U in w(1))		// for every empty space in area tagged "1" (level 1)...
			w=new(U)		// ...create a wall where the empty space used to be
		spawn(200) S()		// new round in 20 seconds

	// Maze generator
	// z: z-level
	// a: Nothing; this is a shortcut for putting var/turf/o/a inside the proc
	P(z,turf/o/a)
		if(w(z)) del(w(z))		// if area "[z]" exists, delete it
		A=new/area				// create an area tagged "[z]" for all the empty spaces
		A:tag="[z]"
		a=new(l(z))				// create a new empty space on the level
		// outer loop:
		// m is a marker; it starts at 15 and bit flags are turned off for every explorable direction
		while(a.m)
			// inner loop 1
			// keep a winding path going until it runs out of places to go.
			while(a.m)
				// pick a random direction
				A=pick(L[8][a.m])
				// take 2 steps in that direction; C is the ending turf, B is the one in the middle
				B=get_step(a,A)
				C=get_step(B,A)
				// mark this direction unexplorable; if it's not now, it will be when we come back
				a.m^=A
				// if C exists, and is dense, and is inside the map confines (avoid the splash screen)
				// ...then it's a wall we can dig toward
				if(C && C:density && C:y<s)
					A=a			// keep track of the turf we're on
					a=new(B)	// create an open space at B
					a=new(C)	// create an open space at C
					a.b=A		// mark the previous turf so we can go back
					sleep		// Bet you didn't know this was the same as sleep()!
				// keep looping until a.m=0.
			// inner loop 2
			// wind back the path until a turf is found that *does* have explorable directions (last it knew)
			// a.b will be null for the turf we started on; it means we're done
			while(!a.m && a.b)
				a=a.b		// go back the way we came
			// either we're back where the whole maze started, or can go back to inner loop 1 now
			sleep
		for(A in 1 to 17)
			B=L(2)		// B is an x value from 4 to 38
			C=L(2)		// C is a y value with the same range
			for(w in range(2,locate(B,C,z)))	// for the 5x5 square centered on B,C,z:
				a=new(w)						// open up that space and delete all walls
			if(z>1)
				B=l(z)			// B is a random location on this level
				l=locate() in B	// find a ladder at this location if any (l is /obj/l)
				if(!l) l=new(B) // if none, then create one going up
		for(a in w(z))	// for every open space in this level
			a.s()		// ...set its icon state
		// if the Stickster wasn't created already, put it somewhere on this level
		if(!S) S=new(l(z))

	// locate something by its tag
	// "0" is the splash screen
	// "9" is the turf with the global list
	// "1" through "6" are levels; each is an area holding all the open spaces
	w(z)
		.=locate("[z]")

	// get a random even number from 2+a to 40-a
	// on any level this will be an open space
	L(a).=rand(1,(s-1)/2-a)*2+a

	// get a random open location on level z, or on any level if z isn't provided
	l(z)
		.=locate(L(),L(),!z?rand(1,world.maxz):z)

atom
	var
		d	// turfs: indicates direction flags for 47-state open space
			// mobs: indicates this is the Stickster
		m	// turfs: bit flags for explorable directions; default 15
			// player: ammo
			// Stickster: mood (0=normal, 1=player spotted)
		b	// turfs: points to a turf back along the maze generator path
		    //        OR distance to nearest target (Stickster AI)
		    // mobs: time to move again
		j	// turfs: junction flag; 1 if this is not a straight hallway or has a ladder
			// Stickster: direction flag (up or down) for finding a ladder to the target player
		k	// turfs: tells Stickster AI to traverse this turf again
			// player: kills
		view	// mobs: movement delay
				// this is actually H in the original code; hence the weird choice of naming it "view"
		n	// turfs: potential directions; 15 for all open turfs, +16 and/or +32 for ladders
			// ladders: direction of ladder
			// mobs: next movement/action
		r	// player: reload timer
			// Stickster: roar timer
		e	// dots: player who fired
			// Stickster: target player
		f	// Stickster: target turf
		h	// hit points (walls: 5, player: 1, Stickster: 3)

	proc
		// play sound
		// a=wav name
		// r=range
		M(a,r=12)
			B=a+L[22]	// "[a].wav"
			C=d?8:0		// if this is the Stickster, play in channel 8
			for(M in P)	// loop through players
				if(M.z==z)
					// play "q[a].wav" if out of range
					M<<sound(!(M in range(r,src))?("q"+B):B,,,C)

		// dummy proc for getting hit
		h()

	New(a,c)		// use a and c as local vars
		if(L)		// if the global list has been loaded
			a=L[25][L[24][type]]	// read the default vars for this type
			for(c in a)				// set vars to their default values
				vars[c]=a[c]

turf
	o	// open space
		New()
			..()	// call atom/New() to initialize values: name="", icon='o.dmi', m=15
			k=w(z)	// find area for this z-level
			k:contents+=src	// add this turf to the area

	w	// solid wall
		h()	// when hit (by dots or Stickster)
			// if this wall is not on the edge, reduce hit points; if hit points are 0...
			if(min(x-1,y-1,s-x,s-y) && !--h)
				M("w")		// play sound "w" (wall crumbling)
				U=new(src)	// create empty space here
				U.b=1e5		// set distance to target at default 100000
				for(U in view(1,U))	// for every space around this, including itself
					U.s()			// ...set icon state

	proc
		// Mark distance to player (a is the minimum found so far by traversing from another turf)
		m(a)
			if(b>a)		// if b (current known distance) is higher, revise it down
				b=a		// set b to new distance
			for(m in L[35])	// for every valid direction (including diagonals)
				A=b			// starting at current distance
				B=v[m]		// get the bit flag that goes with this direction; north=1, east=4, south=16, etc.
				U=src		// set U to the current turf
				while(U.d&B)	// while U has an open space in the direction of m
					U=get_step(U,m)	// find the next open space
					if(U.b<=++A)	// if its known distance is no more than a+distance from src, we're done
						break
					// keep going--lower the known distance for this turf
					++.		// be sure to return non-zero (not done traversing)
					U.b=A	// set b for that turf to the new, lower distance estimate
					U.k=U.j	// mark the turf for re-traversal if it's a junction
			k=0	// done traversing this turf; don't traverse it again

		// Find direction flags for 47-state open space
		s()
			d=0		// reset flags to 0
			for(. in L[35])	// using . (the return value) as a local var to loop through every direction,
				o(.)		// ...test for open space in each direction
				// remove diagonal flags if there is a wall to either side
				d&=(d<<7|d>>1)&d<<1|85
			icon_state="[d]"
			// mark this as a junction if it's not a N-S or E-W hallway (17 or 68)
			// the ^ operator is used like !=
			j=d^17 && d^68
			n=15			// movement may be possible NSEW
			for(l in src)	// for every ladder here...
				n|=l.n		// ...update the movement direction flags; +16 for down, +32 up
				j=1			// ...mark this as a junction because a ladder is here

		// Check for open space in direction a
		o(a)
			// if the next turf in this direction is a /turf/o, mark the directional flag
			if(istype(get_step(src,a),type)) d|=v[a]

obj
	l	// ladder
		// the optional 2nd argument is used if this ladder is the mate to another on a lower level
		New(a,c)	// c is the location of the matching ladder on the lower level, if any
			..()	// load default vars
			if(c)
				n=16			// direction: down
				icon_state="d"	// set icon state for down ladder
			else
				n=32			// direction : up
				l=new(get_step(src,32),loc)	// create a matching ladder on the level above (z-1)
			loc:s()	// call turf's s() proc to reset direction and movement flags (d and n)

	d	// dots
		Move()
			if(loc.n&dir)	// if movement is possible in the current direction, move;
				return ..()	// this check prevents dots going up/down ladders from going on forever
			if(src) del(src)	// can't go up/down anymore; delete

		New(a,c)	// c is the player who fired
			..()	// load default vars
			e=c		// set var to indicate who owns these dots
			M("d")	// play "d" sound: dotgun firing
			walk(src,e:dir,0)	// move in the direction the player is facing; may be up or down
			spawn(6)			// move up to 6 tiles, then delete
				if(src) del(src)

		Bump(a)
			a:h(e)				// call the target's hit proc and tell it who fired these dots
			if(src) del(src)	// delete dots

	b	// bones
		New(a,c)	// a is the location, c is the thing that just croaked
			..()		// load default vars, including icon_state="b"
			icon=c:icon	// set the icon to match c's
			spawn(2e3)	// in 200 seconds (3:20), delete this
				if(src) del(src)

mob
	/*
		Most of the overridden procs are intended for players.
		Most of the procs declared specifically for mobs are for the Stickster.
	 */
	Stat()
		A=p-world.time		// find time remaining
		if(A>0)				// if in a round...
			stat(L[17]+"[A/600%60]:[A/100%6][A/10%10]")	// show time remaining; L[17] is part of the message
			stat("At [x]-[y]-[z]")						// show location
			stat(L[9]+"[m]"+L[10])						// show shots left; L[9] and L[10] are part of the message
			if(S)
				// show Stickster "on level [S.z]" or "to [direction] ([distance])"
				// get_dir()+1 is used because get_dir() may sometimes be 0
				stat(L[11]+(S.z^z?L[12]+"[S.z]":"to [L[3][get_dir(src,S)+1]] ([get_dist(src,S)])"))
		s()		// output status line to show kills for this player
		for(M in P-src)
			if(M) M.s()		// show status line for other mobs
			else P-=M		// remove nulls from list (just in case)

	Login()
		name=L[21]+name		// add "\proper" to the name
		src<<L[6]			// display welcome message
		loc=world.time<p?l():w(0)	// move player to random location, or splash screen if not in a round
		if(!P.len)					// first player to log in is the host
			world.status=name+L[13]	// tell the world who's hosting
			verbs+=L[29]			// add /mob/proc/Kick to verbs available; admin on the cheap
		P+=src				// add player to the list of players
		if(G) k=G[name]		// if there's a list of persistent scores, look up the old score
		k(--k)				// reduce kills, then re-increment with k(), in order to find a place in the list
		P<<"<B>[name][L[14]]</B>"	// tell everyone this player is here

	Logout()
		if(G) G[name]=k		// if there's a list of persistent scores, record the current score
		P<<"<B>[name][L[15]]</B>"	// hey everyone, he's leaving
		P-=src						// remove from the players list
		if(!P.len)					// if this was the host, kill off the Stickster for proper shutdown
			if(S) del(S)
		if(src) del(src)			// delete this mob

	Move(a,c)				// remember, a=new loc, c=direction (optional)
		if(!loc) return		// well, this part's obvious; it's a sanity check
		if(c) dir=c			// if there's a direction flag on this, change direction even if we can't move yet
		// try moving in direction c; if planning to fire (bit flag 64), still do that
		// b() will return non-zero if it isn't time to move yet
		if(b(n&64|c)) return
		// try moving in the direction indicated
		C=loc.d			// get bit flags for this turf
		if(c&c-1 && !(C&v[c]))	// if c is diagonal but there's not a clear path that way
			A=C&v[c&3]?c&3:0	// if north or south part of the diagonal is clear, A is that direction
			B=C&v[c&12]?c&12:0	// if east or west part is clear, B is that direction
			C=A|B				// C will be one or the other; direction is now either N, S, E, or W
			return c(!C || C==c ? c&pick(3,12) : C)	// if blocked or open both ways, pick just one
		.=..()
		if(.) n(view)	// if movement is possible, don't move until time expires
		// "view" is the var named for time needed to move again

	h(a)	// hit by a; the Stickster overrides this proc but uses some of this code
		// announce the kill; L[23] is a list of 3 <I> styles
		if(a) P<<L[23][d+a:d*2+1]+"[a] kills [src]!</I>"
		// the if() above is mandatory because player may log out
		new/obj/b(loc,src)	// create bones
		if(!d)				// if this is just a player
			M(a:d?"k":"t")	// play sound "k" (Stickster kills player) or "t" (player gets shot)
			// if attacker was the Stickster, call a:e() to reset
			// if a player, call a:e() to penalize score unless victim's score was negative
			if(a:d || k>=0) a:e()
			icon_state="n"	// invisible until respawn
			density=0
			spawn(20)		// but in 2 seconds:
				density=1
				if(world.time<p)	// if the round isn't over
					loc=l()			// respawn at a random location
				icon_state=""		// reset icon state
				m=6					// ...and ammo
				r=0					// ...and reload time
			n(20)			// don't move for 2 seconds

	proc
		Kick()	// host-only verb; declared as a proc so others don't have it
			set category=null	// keep this verb off the stat panel
			M=input(L[30],L[31]) as null|mob in P-src	// ask who (else) to kick
			if(M)
				P<<L[32]+M.name+L[33]	// announce the kick
				M.Logout()				// yer outta here!

		// increment score and move up in player list
		// move up until another player of equal or higher score is found
		k()
			++k
			A=P.Find(src)
			while(A>1)
				M=P[A-1]			// find player above this one
				if(M.k>=k) return	// all sorted; we're done
				P[A--]=M			// keep moving up; swap places with M
				P[A]=src

		// decrement score and move down in player list
		e()
			--k
			A=P.Find(src)
			while(A<P.len)
				M=P[A+1]
				if(M.k<=k) return
				P[A++]=M
				P[A]=src

		// don't move for [a] ticks
		n(a)
			n=0				// next move: nothing
			b=world.time+a	// set time to move again

		// reload dotgun
		d()
			if(r>world.time)	// if it's not time to reload
				spawn(r-world.time) d()	// call this proc later
			else
				m=min(++m,6)		// one more shot (up to 6)
				r=world.time+30		// reload again in 3 seconds

		// show # of kills and place in list; called by Stat()
		s()
			stat(name,"[k] kill\s ([P.Find(src)]\th)")

		// prepare to move when time elapses; this is buggy in 334 because of a spawn() bug
		// spawn() fires off a tick too early
		a(a)
			if(b>world.time)	// if not ready to move yet
				if(!n)				// if no plans to move
					spawn(b-world.time) a()	// try again later
				n=a						// set flag for next movement
				return b-world.time		// return time left before move
			if(n&64) f()	// if planning to shoot, fire
			else if(n) c(n)	// move in direction n

		// if not ready to move yet, prepare to do so and return non-zero
		// otherwise, return zero/null to indicate that movement can proceed now
		b(a)
			if(b>world.time)
				.=a(a)
				n=a

		// move in direction a
		c(a)
			if(loc.n&a)						// if movement this way is possible,
				.=Move(get_step(src,a),a)	// do so and return the result

		// fire dotgun
		f()
			// if not able to fire (already firing or dead), or not ready, abort
			// b(n|64) says: prepare to fire in direction about to move, and do so if it returns 0 or null
			if(icon_state || b(n|64)) return
			// if the plan was to turn and fire at the same time, turn now
			if(n&63) dir=n&63
			icon_state="f"		// adopt firing pose
			if(m)				// is this thing loaded?
				new/obj/d(loc,src)	// fire the dots
				--m					// reduce ammo
				spawn(30) d()		// schedule a reload in 3 seconds
			else				// no ammo!
				M("c",0)			// click sound
			n(3)				// no movement for 3 ticks
			spawn(3)			// reset icon_state (unless dead) in 3 ticks
				// icon_state will become something else if dead, so the if() is necessary
				if(icon_state=="f") icon_state=""

		v(a)
			// return non-zero if a is visible to src in maximum limit of vision
			.=(a in view(s,src))

		// step to a
		g(a)
			if(!m())	// if there's no player nearby to be crunched (if so do it)...
				c(get_dir(src,a))			// walk toward a
				sleep max(b-world.time,0)	// sleep until movement is possible again

		// find any /mob/p in view
		p()
			.=locate(.p) in view(s,src)

		// if a player is in reach, kill, kill, kill! (if possible!)
		m()
			sleep max(b-world.time,0)	// extra sleep for stability; wait until movement is possible
			M=locate() in view(1,src)
			if(M) .=c(get_dir(src,M))	// return non-zero if we could move toward player
			sleep max(b-world.time,0)

		// roar
		// sound r1: regular roar
		// sound r2: pursuit roar; player has been spotted already
		// sound r3: scream; player was just sighted
		r(a)	// a is optional and indicates a type of roar (by number)
			if(a)	// if instructed to roar now
				M("r[a]")	// sound "r[a]" (a=1 to 3)
				r=rand(30,99)/a+world.time	// set time to next roar
			if(r<=world.time)	// if it's time to roar again, roar according to mood
				r(m+rand(1,2))

		// reset AI distance calculations
		o()
			for(U in w(z))	// for every open space in the level
				U.b=1e5		// set its distance to target at 100000

		// traverse level (one pass) for AI distance calculations
		j()
			for(U in w(z))		// for every open space in the level
				if(U.k)			// if marked for traversal
					.+=U.m(U.b) // traverse it and add to output; stop traversing when . is 0

		// calculate distance to target
		fn()
			while(!p() && j())	// if no player is in view, and we need to keep traversing,
				sleep 1			// traverse and sleep
			f=loc				// next turf to go to: same as current loc
			for(U in range(4,src)-view(src))	// look for open turfs up to 4 tiles away that aren't in view
				if(U.b<f:b-20 || !U.b)	// if 20+ tiles closer to target or the target is right there
					f=U					// go there; even break through walls to do so
					return
			if(!p())			// if no player in view
				for(A in L[35])			// for every direction...
					U=get_step(src,A)	// get the next turf over
					while(f:d&v[A] && U.b<f:b)	// if A is a valid direction to go, and leads closer
						f=U				// destination is the next turf, or maybe farther along...
						U=get_step(f,A) // check the next turf in that direction
					if(loc!=f) return	// if a new destination has been found, we're done

		// AI level 1: Choose a target
		A()
			spawn	// necessary to avoid recursion
				e=p()				// pick a player from view
				if(e) return C()	// if a player is in view, go to AI proc C
				m=0		// reset mood to 0: hunting
				M=locate() in w(z)	// find any player at all on the level
				e=!M?P[P.len]:M		// target that player, or if none is available, target the current loser
				if(e:z^z)			// if target isn't on this level, find a ladder
					j=e:z>z?16:32	// set j to direction of necessary ladder
					e=/obj/l		// set e to a type path so AI level 2 seeks a ladder
					o()				// reset AI distance calculations
					for(l in w(z))	// for every ladder on this level
						if(l.n&j)		// if this ladder goes the right direction
							l.loc:m(0)	// mark its turf as distance 0 from target, so j() can traverse
				B()		// go to AI level 2

		// AI level 2: Follow a target
		B()
			spawn
				while(e)	// while a target exists
					if(v(e)) return C()	// if target is in view, go to AI level 3
					if(p()) return A()	// if a different player is in view, go to AI level 1
					if(ismob(e))	// if tracking a player...
						if(e:z^z) break	// if the player isn't on this level, break out of the loop
						o()				// reset AI distance calculations
						for(M in w(z))	// for every player on the level...
							M.loc:m(0)  // ...mark turf as distance 0 from target, so j() can traverse
					fn()	// traverse turfs to find new turf to walk to
					if(!f)  // if no target turf, wait a few ticks
						sleep 3
					while(f && loc!=f)
						r()				// roar (if ready)
						g(f)			// go toward that turf
						if(p()) break	// if a player is in view, leave loop
					if(ispath(e))		// if looking for a ladder
						for(M in w(z))	// if any players are on the level
							e=0			// reset target
						if(e)
							for(l in loc)	// for every ladder at this spot
								if(l.n&j)	// if the ladder goes the right way
									c(j)	// follow it
									sleep
									e=0
				A()		// go back to AI level 1

		// AI level 3: Chase a player
		C()
			spawn
				r()				// roar, if ready
				while(e && v(e))
					if(!m)		// if not excited
						m=1		// become excited
						r(3)	// and scream!
					g(get_step_to(src,e))		// try to run toward player; dodge obstacles
				B()		// go back to AI level 2

	verb
		Say(a as text)
			set category=null	// keep this verb off the stat panel
			if(a)
				P<<"<B>[name]:</B> [html_encode(a)]"	// talk

		Up()
			set category=null
			if(loc) c(32)

		Down()
			set category=null
			if(loc) c(16)

		Help()
			set category=null
			for(. in L[5]) src<<browse_rsc(.)	// use . as a local var; send all files in L[5] to the player
			src<<browse(L[4])					// send the HTML help file listed as L[4]

		Who()
			set category=null
			A=P-(P-view(src)+src)		// A is a list of other players in view
			if(world.time<p && A:len)	// if in a round, and there are players in view
				B=L[26]					// start of output line
				for(M in A)
					B+="- [M] ([M.k]) "	// add players to line
				src<<B+L[27]			// output the full line

	s	// /mob/s is the Stickster
		New()
			..()	// load default vars
			A()		// start AI level 1

		Bump(a)
			a:h(src)	// hit the player (or wall)

		// a kill is made!
		e()
			e=0		// no target player/ladder
			f=loc	// no target turf
			n(40)	// don't move for 4 seconds

		h(a)
			if(!--h)	// if out of hit points
				..()
				M("s")		// death sound
				if(a) a:k()	// increment player's kills (unless the player has logged out!)
				e=src		// we're about to del(src), but need to hold onto this proc
				src=0		// set src to 0 so this proc keep srunning
				del(e)		// kill this actual mob; the proc keeps going
				if(world.maxz<6) P(++world.maxz)	// generate a new maze level (up to 6) and Stickster
				else S=new(l())						// or create a new Stickster at a random location
			else
				M("h")		// hurt sound

	p	// /mob/p is a player; no special definitions are needed

client/Center()
	if(world.time<p) mob.f()	// fire dotgun, but only during a round
